#!/bin/bash

################################################################################
#
# This script upgrades existing installation of UniMRCP server with Microsoft
# Bing SR and SS plugins to use Microsoft Azure SR and SS plugins.
# 
# The script is made for Debian-based Linux distributions.
#
# Revision: 2
#
################################################################################

UNIMRCP_CONF_DIR="/opt/unimrcp/conf"
UNIMRCP_VAR_DIR="/opt/unimrcp/var"

echo ""
echo "==================================================="
echo "      Upgrading from Bing to Azure Plugins         "
echo "==================================================="
echo ""

################################################################################
# Step 1: Check whether the unimrcp service is active.

echo -n "Checking whether unimrcp service is active... "
if systemctl is-active unimrcp.service |  grep -w "active"; then
    echo -n "Stopping active unimrcp service... "
    systemctl stop unimrcp.service
    echo "done."
else
    echo "inactive."
fi

################################################################################
# Step 2: Rename the configuration files and the content.

# Step 2.1: Rename the configuration files.
rename 's/bing/azure/' $UNIMRCP_CONF_DIR/umsbing*.xml

# Step 2.2: Rename the content.
sed -i 's/umsbing/umsazure/g' $UNIMRCP_CONF_DIR/umsazuresr.xml
sed -i 's/umsbing/umsazure/g' $UNIMRCP_CONF_DIR/umsazuress.xml
sed -i 's/umsbing/umsazure/g' $UNIMRCP_CONF_DIR/umsazurevoices.xml

# Step 2.3: Revert back to look for existing licenses starting with 'umsbing'. This step is relevant only if node-bound licenses are installed.
sed -i 's/umsazuresr_/umsbingsr_/g' $UNIMRCP_CONF_DIR/umsazuresr.xml
sed -i 's/umsazuress_/umsbingss_/g' $UNIMRCP_CONF_DIR/umsazuress.xml

# Step 2.4: Rename the plugin names in unimrcpserver.xml.
sed -i 's/umsbing/umsazure/g' $UNIMRCP_CONF_DIR/unimrcpserver.xml

# Step 2.5: Rename the logger sources in logger.xml.
sed -i 's/UMSBING/UMSAZURE/g' $UNIMRCP_CONF_DIR/logger.xml

################################################################################
# Step 3: Remove the status files, if any.

find $UNIMRCP_VAR_DIR/status -name 'umsbing*.status' -delete

################################################################################
# Step 4: Remove the wave files and JSON records, if any.

find $UNIMRCP_VAR_DIR -name 'umsbing*.wav' -delete
find $UNIMRCP_VAR_DIR -name 'umsbing*.json' -delete

################################################################################
# Step 5: Remove the Bing deb packages.

dpkg --remove unimrcp-bing-sr
dpkg --remove unimrcp-bing-ss

################################################################################
# Step 6: Install the Azure deb packages.

apt-get update
apt-get install unimrcp-azure-sr
apt-get install unimrcp-azure-ss

################################################################################
# Step 7: Start the unimrcp service.

echo -n "Starting unimrcp service... "
systemctl start unimrcp.service

################################################################################
# Step 8: Done.

echo ""
echo "Upgrade complete."
echo ""
exit 0
